#!/usr/bin/env python
# encoding=utf-8


def test():
    print('success')